==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/MutationCreateRetentionDrillDownSegmentParametrizedInput.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLParametrizedInput;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequestSerializer;
import java.util.StringJoiner;

/**
 * Parametrized input for field createRetentionDrillDownSegment in type Mutation
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class MutationCreateRetentionDrillDownSegmentParametrizedInput implements GraphQLParametrizedInput {

    @javax.validation.constraints.NotNull
    private String projectId;
    @javax.validation.constraints.NotNull
    private RetentionDrillDownSegmentInputDto retentionDrillDownSegment;

    public MutationCreateRetentionDrillDownSegmentParametrizedInput() {
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput(String projectId, RetentionDrillDownSegmentInputDto retentionDrillDownSegment) {
        this.projectId = projectId;
        this.retentionDrillDownSegment = retentionDrillDownSegment;
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput projectId(String projectId) {
        this.projectId = projectId;
        return this;
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput retentionDrillDownSegment(RetentionDrillDownSegmentInputDto retentionDrillDownSegment) {
        this.retentionDrillDownSegment = retentionDrillDownSegment;
        return this;
    }


    @Override
    public String toString() {
        StringJoiner joiner = new StringJoiner(", ", "(", ")");
        if (projectId != null) {
            joiner.add("projectId: " + GraphQLRequestSerializer.getEntry(projectId));
        }
        if (retentionDrillDownSegment != null) {
            joiner.add("retentionDrillDownSegment: " + GraphQLRequestSerializer.getEntry(retentionDrillDownSegment));
        }
        return joiner.toString();
    }

}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/MutationCreateRetentionDrillDownSegmentParametrizedInput.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLParametrizedInput;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequestSerializer;
import java.util.StringJoiner;

/**
 * Parametrized input for field createRetentionDrillDownSegment in type Mutation
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class MutationCreateRetentionDrillDownSegmentParametrizedInput implements GraphQLParametrizedInput {

    @javax.validation.constraints.NotNull
    private String projectId;
    @javax.validation.constraints.NotNull
    private RetentionDrillDownSegmentInputDto retentionDrillDownSegment;

    public MutationCreateRetentionDrillDownSegmentParametrizedInput() {
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput(String projectId, RetentionDrillDownSegmentInputDto retentionDrillDownSegment) {
        this.projectId = projectId;
        this.retentionDrillDownSegment = retentionDrillDownSegment;
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput projectId(String projectId) {
        this.projectId = projectId;
        return this;
    }

    public MutationCreateRetentionDrillDownSegmentParametrizedInput retentionDrillDownSegment(RetentionDrillDownSegmentInputDto retentionDrillDownSegment) {
        this.retentionDrillDownSegment = retentionDrillDownSegment;
        return this;
    }


    @Override
    public String toString() {
        StringJoiner joiner = new StringJoiner(", ", "(", ")");
        if (projectId != null) {
            joiner.add("projectId: " + GraphQLRequestSerializer.getEntry(projectId));
        }
        if (retentionDrillDownSegment != null) {
            joiner.add("retentionDrillDownSegment: " + GraphQLRequestSerializer.getEntry(retentionDrillDownSegment));
        }
        return joiner.toString();
    }

}
